@@ -19,9 +19,7 @@ import roundup.date
 ### Exceptions
 
 class ConfigurationError(Exception):
-
-    # without this, pychecker complains about missing class attribute...
-    args = ()
+    pass
 
 class NoConfigError(ConfigurationError):
 
