@@ -428,12 +428,17 @@ class MailGW:
         return 0
 
 
-    def do_apop(self, server, user='', password=''):
+    def do_apop(self, server, user='', password='', ssl=False):
         ''' Do authentication POP
         '''
-        self.do_pop(server, user, password, apop=1)
+        self._do_pop(server, user, password, True, ssl)
 
-    def do_pop(self, server, user='', password='', apop=0):
+    def do_pop(self, server, user='', password='', ssl=False):
+        ''' Do plain POP
+        '''
+        self._do_pop(server, user, password, False, ssl)
+
+    def _do_pop(self, server, user, password, apop, ssl):
         '''Read a series of messages from the specified POP server.
         '''
         import getpass, poplib, socket
@@ -449,7 +454,11 @@ class MailGW:
 
         # open a connection to the server and retrieve all messages
         try:
-            server = poplib.POP3(server)
+            if ssl:
+                klass = poplib.POP3_SSL
+            else:
+                klass = poplib.POP3
+            server = klass(server)
         except socket.error:
             self.logger.exception('POP server error')
             return 1
@@ -616,7 +625,7 @@ Emails to Roundup trackers must include a Subject: line!
         delim_close = re.escape(close)
         if delim_close in '[(': delim_close = '\\' + delim_close
         subject_re = r'''
-        (?P<refwd>\s*\W?\s*(fw|fwd|re|aw)\W\s*)*\s*   # Re:
+        (?P<refwd>\s*\W?\s*(fw|fwd|re|aw|sv|ang)\W\s*)*\s*   # Re:
         (?P<quote>")?                                 # Leading "
         (%s(?P<classname>[^\d\s]+)                    # [issue..
            (?P<nodeid>\d+)?                           # ..1234]
